markuptools.Markup
==================

.. abjad-lineage:: abjad.tools.markuptools.Markup.Markup.Markup

.. autoclass:: abjad.tools.markuptools.Markup.Markup.Markup
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.contents
   :noindex:

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.indented_lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.markup_name
   :noindex:

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.start_component
   :noindex:

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.direction
   :noindex:

Methods
-------

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.attach
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.detach
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__call__
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__delattr__
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__eq__
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__ge__
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__gt__
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__hash__
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__le__
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__lt__
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__ne__
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__repr__
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__str__
   :noindex:
